@@ -38,6 +38,7 @@ class ChGL : public QGLWidget{
 Q_OBJECT
 public:
     explicit ChGL(QWidget * parent = 0);
+    virtual ~ChGL();
     void setMainWindow(QWidget * parent){
     chparent=parent;
     }
@@ -46,7 +47,6 @@ public:
 	minus;//!<for streo mode swiches right and left eye view
     int stereo_mode;//!< intager value of the current stereo mode
     int objCnt;//!< number of visible atoms + q-peaks
-    double xrdist;//!< distance for x-ray view cut planes
     int ImeanThisAtom;//!< atom index for context menu. 
     double viewAngle,//!< viewing angele for the perspective view 0 is othogonal 
 	   envirange;//!< range in Angstrom around which environmental atoms should be consedered.
@@ -95,10 +95,10 @@ public:
     QMenu *sfacMenu;//!< a sub menu to change the element of a specified atom.
     QStringList labs;//!< Labels for an envi-ronment list.
     Molecule *mol;//!< pointer to the Molecule object.
-    int bas,//!< GL List base for atoms bonds unit cell.
-	murx,//!< non zero values lead to a rerendering of the display lists. 
-	foubas[37],//!< GL List base for the fourier maps.
-	wirbas;//!< GL List base for wireframe bonds and atoms.
+    int	murx;//!< non zero values lead to a rerendering of the display lists. 
+    static const int bas=1;//!< GL List base for atoms bonds unit cell.
+    static const int wirbas=11;//!< GL List base for wireframe bonds and atoms.
+    int foubas[37];//!< GL List base for the fourier maps.
     double L;//!< a scale factor.
     QAction *foact, //!< QAction toggling Fobs maps.
 	    *fofcact;//!< QAction toggling Fobs-Fcalc maps.
@@ -128,6 +128,7 @@ signals:
     void message(const QString &);//!< small text messages to the status bar.
     void bigmessage(const QString &);//!< passes HTML strings to the info window.
     void jumpit(int index);//!<An atom has ben left clicked: cursor jump on it.
+    void selectionChanged();
     void diffscroll(int numsteps,int diff);//!< to change the iso value of the Fo- or Fo-Fc maps
     void neuemitte(V3 mitte);//!< the rotation center has changet to mitte.
     void inimibas();//!< tells FourXle to initialize the GL display lists.
@@ -184,9 +185,9 @@ public slots:
     void setAtom(bool b);
     void setBGGradient(bool b);
     void setBond(bool b);
-    void setDepthCueing(bool b);
     void setHBond(bool b);
     void setLabel(bool b);
+    void setMSAA(bool b);
     void setMatrix();
     void setMolecule(Molecule *m);
     void setReNaMo(bool b);
@@ -199,7 +200,6 @@ public slots:
     }
     void setUnit(bool b);
     void setViewAngle(double ang);
-    void setXRayView(bool b);
     void showHidden();
     void showMatrix();
     void zoomOut();
@@ -242,13 +242,12 @@ private:
         void swipeTriggered(QSwipeGesture*);
 #endif
         bool mouseOverInteraction,atomsClickable,tubes,bggradient;
-	bool drawAx,drawUc,drawAt,drawADP,drawBo,drawLa,drawHb,drawFO,drawDF,xray_vision,depthcueing,
+	bool drawAx,drawUc,drawAt,drawADP,drawBo,drawLa,drawHb,drawFO,drawDF,
 	    // warfaul,
 	     warLabel;
         int imFokus,afok;
 	void draw();
         //void highFocus();
-	int xray_eye,fogrange;
 	GLuint selectBuf[MAXSELECT];
 	GLfloat feedBuf[3000];
         GLint vp[4];
