@@ -43,6 +43,7 @@
 
 #include "codeeditor.h"
 #include "shx_helper.h"
+#include "window.h"
 //#include "chgl.h"
 
 CodeEditor::CodeEditor(QWidget *parent) : QPlainTextEdit(parent), c(0){
@@ -437,6 +438,9 @@ void  CodeEditor::contextMenuEvent(QContextMenuEvent *event) {
          a=menu->addAction(QString("select atoms in structure found in selected text"),
                          this, SLOT(selectInStructure()));
          a->setData(textCursor().selectedText());
+         a=menu->addAction(QString("sort atoms found in selected text"),
+                         this, SLOT(ortInStructure()));
+         a->setData(textCursor().selectedText());
 	 a=menu->addAction(QString("toggle remarks states of selected text"),
 			 this,SLOT(toggleRemarks()));
      }
@@ -497,6 +501,12 @@ void CodeEditor::selectInStructure(){
     if (action)
         emit electInStructure(action->data().toString());
 
+}
+void CodeEditor::ortInStructure(){
+    QAction *action = qobject_cast<QAction *>(sender());
+    if (action)
+        emit sortInStructure(action->data().toString());
+
 }
 
 void CodeEditor::setCompleter(QCompleter *completer){
@@ -568,10 +578,21 @@ void CodeEditor::focusInEvent(QFocusEvent *e){
 void CodeEditor::keyPressEvent(QKeyEvent *e){
 //    printf("kp\n");
 //    if (!chgl->mol->selectedatoms.isEmpty()){
-    if ((e->modifiers() & Qt::ControlModifier)&&(e->key()==Qt::Key_Delete)) {
+  // Pressing F1 when the mouse cursor is over a SHELX command will
+  // open the SHELXL help text:
+  if (e->key() == Qt::Key_F1) {
+    QTextCursor tc = textCursor();
+    tc.select(QTextCursor::WordUnderCursor);
+    QString txt = tc.selectedText().toUpper();
+    if ( Window::isacommand(txt) >= 0 ) {
+      QUrl help_url = QString("http://shelx.uni-goettingen.de/shelxl_html.php#%1").arg(txt);
+      QDesktopServices::openUrl(help_url);
+    }
+  }
+  if ((e->modifiers() & Qt::ControlModifier)&&(e->key()==Qt::Key_Delete)) {
       	e->ignore();
         emit deleteSelected();
-	return;
+    return;
     }
     //}
     if (c && c->popup()->isVisible()) {
