@@ -18,18 +18,22 @@
  ****************************************************************************/
 #include "eacDlg.h"
 #if defined (Q_WS_MAC)
-#include <glu.h>
+#include <OpenGL/glu.h>
+//#include <glu.h>
 #else
 #include <GL/glu.h>
 #endif
 #include "itsme.h"
+#ifndef GL_MULTISAMPLE
+#define GL_MULTISAMPLE  0x809D
+#endif
 /*
    extern void __RotateCS( double c, double s, double& X, double& Y );
    extern void glTranslateL( const double dx, const double dy, const double dz );
    extern void glRotateL( const double dang, const double x, const double y, const double z );
    */
 
-EacGLW::EacGLW(Molecule *externMole, QWidget * parent){
+EacGLW::EacGLW(Molecule *externMole, QWidget * parent): QGLWidget(QGLFormat(QGL::SampleBuffers),parent){
   this->setParent(parent);
   mol=externMole;
   exmin=mol->pmin;
@@ -184,22 +188,27 @@ EacGLW::EacGLW(Molecule *externMole, QWidget * parent){
      */
 }
 
-void EacGLW::draw(){
-  if (mol->LOD>3) {
-    const GLfloat  OBJ_SPE[]   = { 0.8, 0.8, 0.8, 1.0 };  
-    const GLfloat  OBJ_SHIN    = 127.0;               
-    glMaterialfv( GL_FRONT_AND_BACK, GL_SPECULAR,             OBJ_SPE  );
-    glEnable     ( GL_COLOR_MATERIAL ) ;
-    glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE ) ;    
-    glMaterialf(  GL_FRONT_AND_BACK, GL_SHININESS,           OBJ_SHIN );
-  }else{
-    const GLfloat  OBJ_SPE[]   = { 0.0, 0.0, 0.0, 1.0 };  
-    const GLfloat  OBJ_SHIN    = 1.0;               
-    glMaterialfv( GL_FRONT_AND_BACK, GL_SPECULAR,             OBJ_SPE  );
-    glEnable     ( GL_COLOR_MATERIAL ) ;
-    glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE ) ;    
-    glMaterialf(  GL_FRONT_AND_BACK, GL_SHININESS,           OBJ_SHIN );
+void EacGLW::setMSAA(bool b){
+  QGLFormat glf = format();
+  printf("sampleBuffers = %d samples %d\n",glf.sampleBuffers(),glf.samples());
+  if (b) {    
+    glEnable(GL_MULTISAMPLE);
   }
+  else  {
+    glDisable(GL_MULTISAMPLE);;
+  }
+  updateGL();
+}
+void EacGLW::draw(){
+  //int pr;
+  //glGetIntegerv(GL_CURRENT_PROGRAM,&pr);
+  //printf("@@@%d %d \n",pr,mol->g_program);
+  const GLfloat  OBJ_SPE[]   = { 0.8, 0.8, 0.8, 1.0 };  
+  const GLfloat  OBJ_SHIN    =  32.0;               
+  glMaterialfv( GL_FRONT_AND_BACK, GL_SPECULAR,             OBJ_SPE  );
+  glEnable     ( GL_COLOR_MATERIAL ) ;
+  glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE ) ;    
+  glMaterialf(  GL_FRONT_AND_BACK, GL_SHININESS,           OBJ_SHIN );
   static double rtx=2.0;  
   glRotated(rtx,1.0,0.0,0.0);
   glRotated(rtx,0.0,1.0,0.0);
@@ -212,7 +221,9 @@ void EacGLW::draw(){
   mol->adp=1;
   mol->intern=1;
   mol->tubes=0;
+  glEnable(GL_CULL_FACE);
   mol->atoms(xd,proba);
+  glDisable(GL_CULL_FACE);
   if (mol->bondColorStyle){
     qglColor(mol->bondColor);
     glDisable(GL_COLOR_MATERIAL);
@@ -234,6 +245,8 @@ void EacGLW::draw(){
   glPopMatrix();
 }
 void EacGLW::initializeGL(){
+  myquad=mol->q;
+  mol->q=gluNewQuadric();
   glEnable(GL_LINE_SMOOTH);  
   glHint(GL_LINE_SMOOTH_HINT,GL_NICEST);
 
@@ -296,6 +309,10 @@ void EacGLW::initializeGL(){
   glDepthFunc(GL_LEQUAL);
   gluLookAt(0.0, 200, 50 ,   0.0, 0.0, 0.0,   0.0, -100, 400 );
   glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);
+  saveProgram=mol->g_Program;
+  mol->g_Program=new QGLShaderProgram(context(),this);
+  mol->g_program=mol->installShader();
+  //g_program=mol->installShader();
 }
 void EacGLW::resizeGL(int width, int height){
   glViewport(0, 0, width, height);        
@@ -584,6 +601,15 @@ void EacDlg::checkWall(){
 void EacDlg::checkSolid(){
   if (sldbx->checkState()&&(walbx->checkState()))sldbx->setCheckState(Qt::Unchecked);
 }
+void EacDlg::checkShader(bool b){
+  bool bb=false;
+  if (b&&(eacGLW->mol->g_Program!=NULL)) bb=eacGLW->mol->g_Program->bind();
+  eacGLW->mol->useShaders = bb;
+
+  mol->einstellung->beginGroup("Window");
+  mol->einstellung->setValue("Use_GLSL_Shaders",bb);
+  mol->einstellung->endGroup();
+}
 void EacDlg::checkBall(){
   if (sphbx->checkState())sldbx->setEnabled(true);
   else sldbx->setEnabled(false);
@@ -642,6 +668,7 @@ void EacDlg::unicolor(bool b){
   update();
 }
 
+
 void EacDlg::strengthChanged(double d){
   eacGLW->mol->bondStrength=mol->bondStrength=d;
   mol->einstellung->beginGroup("Bonds");
@@ -1067,13 +1094,23 @@ EacDlg::EacDlg(Molecule *externMole){
   glt->addLayout(glt4);
   glt->addLayout(glt6);
   glt->addLayout(glt5);
+  shaderUse = new QCheckBox("Use GLSL shader for atoms");
+  if (mol->g_program&&mol->shaders_work){
+    shaderUse->setChecked(mol->useShaders); 
+    connect(shaderUse ,SIGNAL(toggled(bool)),this,SLOT(checkShader(bool)));
+  }else{
+    mol->useShaders=false;
+    shaderUse->setChecked(mol->useShaders); 
+    shaderUse->setDisabled(true); 
+  }  
+  glt->addWidget(shaderUse);
   globalStuff->setLayout(glt);
   walbx = new QCheckBox("Draw intersecting planes");
-  walbx->setTristate();
-  rinbx = new QCheckBox("Draw principal ellipses");
+  //walbx->setTristate();
+  rinbx = new QCheckBox("Draw principal ellipses (check again for black or white)");
   rinbx->setTristate();
   sphbx = new QCheckBox("Draw ellipsoid surface");
-  sldbx = new QCheckBox("Solid ellipsoid");
+  sldbx = new QCheckBox("Solid closed ellipsoid");
   noadp = new QCheckBox("No ADP");
   metalic = new QCheckBox("Dashed Bonds to others");
   nlabx = new QCheckBox("No label!");
@@ -1171,6 +1208,7 @@ EacDlg::EacDlg(Molecule *externMole){
   connect(sldbx,SIGNAL(stateChanged(int)),eacGLW,SLOT(soldA(int)));
   connect(sldbx,SIGNAL(stateChanged(int)),this,SLOT(checkWall()));
   connect(metalic,SIGNAL(stateChanged(int)),eacGLW,SLOT(metalA(int)));
+  eacGLW->setMSAA(true);
 }
 
 void EacDlg::doMulti(){
@@ -1212,7 +1250,7 @@ MultiStyle::MultiStyle(Molecule *externMole){
   QLabel *staL =new QLabel("From: "); 
   QLabel *endL =new QLabel("To: "); 
   walbx = new QCheckBox("Draw intersecting planes");
-  walbx->setTristate();
+  //walbx->setTristate();
   rinbx = new QCheckBox("Draw principal ellipses");
   rinbx->setTristate();
   sphbx = new QCheckBox("Draw ellipsoid surface");
@@ -1257,6 +1295,7 @@ void MultiStyle::checkBall(){
 
 void EacDlg::reject(){
   eacGLW->timer->stop();
+  mol->q=eacGLW->myquad;
   /*
      int i=eacGLW->xd.at(0).an;
   //  extern molekul mol; 
@@ -1289,6 +1328,10 @@ void EacDlg::reject(){
   psew->disconnect();
   eacGLW->disconnect();
   this->disconnect();
+
+  mol->g_Program->release();
+  mol->g_Program->deleteLater();
+  mol->g_Program=eacGLW->saveProgram;
   delete eacGLW;
   done(QDialog::Rejected);
 }
@@ -1323,5 +1366,8 @@ void EacDlg::accept(){
   psew->disconnect();
   eacGLW->disconnect();
   this->disconnect();
+  mol->g_Program->release();
+  mol->g_Program->deleteLater();
+  mol->g_Program=eacGLW->saveProgram;
   done(QDialog::Accepted);
 }
