@@ -211,10 +211,10 @@ void FcVsFo::readFCF(){
 			      sqrt(
 					      obs.h*obs.h*cell.as*cell.as+
 					      obs.k*obs.k*cell.bs*cell.bs+
-					      obs.l*obs.l*cell.cs*cell.cs+
-					      2*obs.h*obs.l*cell.as*cell.cs+cell.cosbe+
-					      2*obs.k*obs.l*cell.bs*cell.cs+cell.cosal+
-					      2*obs.h*obs.k*cell.as*cell.bs+cell.cosga)/2.0;
+                          obs.l*obs.l*cell.cs*cell.cs+
+                          2*obs.h*obs.l*cell.as*cell.cs*cell.cosbe+
+                          2*obs.k*obs.l*cell.bs*cell.cs*cell.cosal+
+                          2*obs.h*obs.k*cell.as*cell.bs*cell.cosga)/2.0;
 
 
 
@@ -250,10 +250,10 @@ void FcVsFo::readFCF(){
 			       sqrt(
 					       obs.h*obs.h*cell.as*cell.as+
 					       obs.k*obs.k*cell.bs*cell.bs+
-					       obs.l*obs.l*cell.cs*cell.cs+
-					       2*obs.h*obs.l*cell.as*cell.cs+cell.cosbe+
-					       2*obs.k*obs.l*cell.bs*cell.cs+cell.cosal+
-					       2*obs.h*obs.k*cell.as*cell.bs+cell.cosga)/2.0;
+                           obs.l*obs.l*cell.cs*cell.cs+
+                           2*obs.h*obs.l*cell.as*cell.cs*cell.cosbe+
+                           2*obs.k*obs.l*cell.bs*cell.cs*cell.cosal+
+                           2*obs.h*obs.k*cell.as*cell.bs*cell.cosga)/2.0;
 		       Fc.append(cal);
 		       Fo.append(obs);
 		     }
@@ -283,10 +283,10 @@ void FcVsFo::readFCF(){
 			       sqrt(
 					       obs.h*obs.h*cell.as*cell.as+
 					       obs.k*obs.k*cell.bs*cell.bs+
-					       obs.l*obs.l*cell.cs*cell.cs+
-					       2*obs.h*obs.l*cell.as*cell.cs+cell.cosbe+
-					       2*obs.k*obs.l*cell.bs*cell.cs+cell.cosal+
-					       2*obs.h*obs.k*cell.as*cell.bs+cell.cosga)/2.0;
+                           obs.l*obs.l*cell.cs*cell.cs+
+                           2*obs.h*obs.l*cell.as*cell.cs*cell.cosbe+
+                           2*obs.k*obs.l*cell.bs*cell.cs*cell.cosal+
+                           2*obs.h*obs.k*cell.as*cell.bs*cell.cosga)/2.0;
 		       Fc.append(cal);
 		       Fo.append(obs);
 		     }
@@ -310,10 +310,10 @@ void FcVsFo::readFCF(){
 			     sqrt(
 					     obs.h*obs.h*cell.as*cell.as+
 					     obs.k*obs.k*cell.bs*cell.bs+
-					     obs.l*obs.l*cell.cs*cell.cs+
-					     2*obs.h*obs.l*cell.as*cell.cs+cell.cosbe+
-					     2*obs.k*obs.l*cell.bs*cell.cs+cell.cosal+
-					     2*obs.h*obs.k*cell.as*cell.bs+cell.cosga)/2.0;
+                         obs.l*obs.l*cell.cs*cell.cs+
+                         2*obs.h*obs.l*cell.as*cell.cs*cell.cosbe+
+                         2*obs.k*obs.l*cell.bs*cell.cs*cell.cosal+
+					     2*obs.h*obs.k*cell.as*cell.bs*cell.cosga)/2.0;
 		     Fc.append(cal);
 		     Fo.append(obs);
 		   }
@@ -343,10 +343,10 @@ void FcVsFo::readFCF(){
 			       sqrt(
 					       obs.h*obs.h*cell.as*cell.as+
 					       obs.k*obs.k*cell.bs*cell.bs+
-					       obs.l*obs.l*cell.cs*cell.cs+
-					       2*obs.h*obs.l*cell.as*cell.cs+cell.cosbe+
-					       2*obs.k*obs.l*cell.bs*cell.cs+cell.cosal+
-					       2*obs.h*obs.k*cell.as*cell.bs+cell.cosga)/2.0;
+                           obs.l*obs.l*cell.cs*cell.cs+
+                           2*obs.h*obs.l*cell.as*cell.cs*cell.cosbe+
+                           2*obs.k*obs.l*cell.bs*cell.cs*cell.cosal+
+					       2*obs.h*obs.k*cell.as*cell.bs*cell.cosga)/2.0;
 		       Fc.append(cal);
 		       Fo.append(obs);
 //		       printf("%d %d %d %f %f\n",obs.h,obs.k,obs.l,obs.F,cal.F);
@@ -504,7 +504,7 @@ void  FcVsFo::graphChange(int type){
 		    minn=10000;
 		    for (int i=0; i<Fo.size(); i++){
 		      double xx=Fo.at(i).F/Fc.at(i).F;
-		      if ((isnormal(xx))&&(xx>0.001)){
+              if ((std_isnormal(xx))&&(xx>0.001)){
 		      minn=qMin(minn,xx);
 		      maxx=qMax(maxx,xx);
 //		      qDebug()<<Fo.at(i).stl<<maxsintl<<xx;
@@ -531,7 +531,7 @@ void  FcVsFo::graphChange(int type){
 			  break;
 		  case 1:{
 			  double xx=fabs(Fo.at(ix).F*Fo.at(ix).F-Fc.at(ix).F*Fc.at(ix).F)/Fo.at(ix).sigma;
-			  if ((isnormal(Fc.at(ix).stl))&&(isnormal(xx))){
+			  if ((std_isnormal(Fc.at(ix).stl))&&(std_isnormal(xx))){
 //			    printf("%g %g\n",Fc.at(ix).stl/maxsintl*500,500-(xx-minn)/(maxx-minn)*500);
 			  drin[i]->moveBy(Fc.at(ix).stl/maxsintl*500,500-(xx-minn)/(maxx-minn)*500);
 			  }
@@ -540,7 +540,7 @@ void  FcVsFo::graphChange(int type){
 			 break;
 		  case 2:{
 			  double xx=Fo.at(ix).F / Fc.at(ix).F;
-			  if ((isnormal(Fc.at(ix).stl))&&(isnormal(xx))){
+			  if ((std_isnormal(Fc.at(ix).stl))&&(std_isnormal(xx))){
 			    drin[i]->moveBy(Fc.at(ix).stl/maxsintl*500,500-(xx-minn)/(maxx-minn)*500);
 			  }
 			  else drin[i]->moveBy(0,500);
@@ -618,9 +618,3 @@ else{
   state->setText(s);
 }
 }
-#ifdef vc7hack
-#include <float.h>
-int isnormal(double arg){
-    return _finite(arg)||(arg==0);
-}
-#endif
