@@ -21,12 +21,15 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
+#include <cmath>
 #include <ctype.h>
 #include <string.h>
 #include <QtGui>
-#ifndef isnormal
-int isnormal(double arg);
-#define vc7hack 1
+#ifdef _MSC_VER
+#include <float.h>
+#define std_isnormal(arg) (_finite(arg)||(arg==0))
+#else
+#define std_isnormal std::isnormal
 #endif
 
 //! Omit is a struct to specify a refection to be omitted by the OMIT instruction
