@@ -241,7 +241,9 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
       n4=n2*n1;
       n5=n3*n4;
       datfo=(float*) malloc(sizeof(float)*n5);
+      if (datfo==NULL)return false;
       datfo_fc=(float*) malloc(sizeof(float)*n5);
+      if (datfo_fc==NULL)return false;
       DX=1.0/n1;
       DY=1.0/n2;
       DZ=1.0/n3;
@@ -255,9 +257,11 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
       dims[2]=n1;
 #ifdef FFTW3_H
       B=(fftwf_complex*)fftwf_malloc(sizeof(fftwf_complex)*n5);
+      if (B==NULL)return false; 
       for (int i=0; i<n5; i++){B[i][0]=0;B[i][1]=0;}
 #else
       B=(kiss_fft_cpx*)KISS_FFT_MALLOC(nbytes = (sizeof(kiss_fft_cpx)*n5));
+      if (B==NULL)return false; 
       for (int i=0; i<n5; i++){B[i].r=0;B[i].i=0;}
 #endif
       for (int i=0; i<nr;i++){
@@ -369,9 +373,13 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
   mole->frac2kart(urs,urs);
 
   nodex= (FNode*)malloc(sizeof(FNode)*n5);
+  if (nodex==NULL)return false; 
   nodey= (FNode*)malloc(sizeof(FNode)*n5);
+  if (nodey==NULL)return false; 
   nodez= (FNode*)malloc(sizeof(FNode)*n5);
+  if (nodez==NULL)return false; 
   noGoMap= (int*) malloc(sizeof(int)*n5*27);
+  if (noGoMap==NULL)return false; 
   for (int no=0;no<(n5*27);no++) noGoMap[no]=0; 
   for (int o=0; o<n5;o++){
     nodex[o].flag=0;
@@ -614,6 +622,7 @@ void FourXle::sorthkl(int nr, Rec r[]){
   /*! sorts the reflection list
    */
   Rec *hilf= (Rec*) malloc(sizeof(Rec)*nr);
+  if (hilf==NULL)return ; 
   int i,j,k,nj,ni,spalte;int index[4096];
   for (spalte=0; spalte<3; spalte++){
     j=-999999;
@@ -742,7 +751,7 @@ void FourXle::gen_surface(bool neu,int imin,int imax){
 //  }
 tri=0;
  for (int fac=imin; fac<imax; fac++){
-    if ((chgl->foubas[fac])&&(glIsList(chgl->foubas[fac]))) glDeleteLists(chgl->foubas[fac],1);
+    //if ((chgl->foubas[fac])&&(glIsList(chgl->foubas[fac]))) glDeleteLists(chgl->foubas[fac],1);
 
     switch (fac){
 	    case 0:                   
@@ -809,7 +818,10 @@ tri=0;
     }
     int mper=(chgl->niceTrans->isChecked())?6:1;
     for (int pers=0;pers<mper;pers++){
-      if (!chgl->foubas[fac+pers*4]) chgl->foubas[fac+pers*4]=glGenLists(1);
+      if (!chgl->foubas[fac+pers*4]) {
+        chgl->foubas[fac+pers*4]=glGenLists(1);
+        //printf("fac %d pers %d fou[%d] %d\n",fac,pers,fac+pers*4,chgl->foubas[fac+pers*4]);
+      }
       glNewList(chgl->foubas[fac+pers*4], GL_COMPILE );
       glLineWidth(linwidth);
 	switch (fac) {
@@ -1269,6 +1281,7 @@ void FourXle::jnk(){
   r=powf((3*(n1-1)*(n2-1)*(n3-1)),1.0f/3.0f);
 //  printf("%d %d %d %d %f\n",n1,n2,n3,n5,r);
   float *datfo_fcstp=(float*) malloc(sizeof(float)*n5);
+  if (datfo_fcstp==NULL)return ; 
   float invstep=100.0f;
   float step=1.0f/invstep;
   float rhomind2=99999.0f,rhomaxd2=-99999.0f;
