@@ -18,7 +18,7 @@
 ****************************************************************************/
 #include "historywidget.h"
 #include <QtGui>
-#define PROGRAM_NAME "shelXle"
+//#define PROGRAM_NAME "shelXle"
 HistoryWidget::HistoryWidget(QWidget *parent) :
     QWidget(parent){
     setMinimumSize(100,100);
