@@ -20,10 +20,23 @@
 #include <QApplication>
 //öß
 void mh(QtMsgType type, const char *msg){
+    QString pth=QDir::homePath()+"/ShelXle_message.txt";
+    FILE *er=fopen(pth.toStdString().c_str(),"wt");
+    fprintf(er,"======\n%s\n======\n",msg);
+    fclose(er);
+    if (strstr(msg,"QGLShader::link:")!=NULL) {
+      printf("%s\n",msg);fflush(stdout);
+      return; // ignore useless error messages with shitty intel graphic cards reporting \"No error."
+    }
   if (strstr(msg,"QAccessibleWidget")!=NULL) {
     printf("%s\n",msg);fflush(stdout);
     return; // ignore useless error messages on win with touch screens
   }
+  if (strstr(msg,"QGLShader::link:")!=NULL) {
+    printf("%s\n",msg);fflush(stdout);
+    return; // ignore useless error messages 
+  }
+
   switch (type){
   case QtDebugMsg:
 
@@ -57,6 +70,7 @@ void mh(QtMsgType type, const char *msg){
 
 int main(int argv, char *args[]){
   QApplication app(argv, args);
+  
   app.setOrganizationName("shelxle");
 //  app.setOrganizationDomain("shelxle");
   qInstallMsgHandler(mh);
