@@ -29,6 +29,13 @@
 #include <QStringList>
 #include <QList>
 #include <QtOpenGL>
+#include <QGLShaderProgram>
+#if defined (Q_WS_MAC)
+#include <OpenGL/glu.h>
+//#include <glu.h>
+#else
+#include <GL/glu.h>
+#endif
 #include <QtCore>
 #ifndef M_PI
 #define	M_PI		3.14159265358979323846
@@ -43,7 +50,19 @@
 #define ATOM_STYLE_PLAID 128
 #define ATOM_STYLE_METAL 256
 #include <QSettings>
+#ifndef GLAPIENTRY
+#if defined(_MSC_VER) || defined(__MINGW32__)
+#define GLAPIENTRY __stdcall
+#else
+#define GLAPIENTRY
+#endif
+#endif
 
+#ifndef GLAPIENTRYP
+#define GLAPIENTRYP GLAPIENTRY *
+#endif
+
+typedef void (GLAPIENTRYP GLU_func_ptr)(void);
 //GLOBAL SETTINGS
 //static int global_zero_counter=0;
 //! V3 is a three dimensional vector in cartesian space
@@ -1121,11 +1140,16 @@ public:
        QColor mQolor;//!< the single Q-Peak color
        double  qboMin,qboMax;
   int LOD;//!< The Level of Detail
+  QGLShaderProgram *g_Program,*saveProg;//shaders with Qt
+  GLuint g_program;//GL handle for shader program
+  GLUquadricObj *q;// global instead of local variable
   Molecule();//!<The constructor
+  int icocnt;
   void setHBondMaxDist(double d);
   void setHBondMaxAngl(double w);
   double hbdist();
   double hbangl();
+  int installShader();
   void Farbverlauf (GLfloat wrt,GLfloat min,GLfloat max);//!<computes a gradient color for wrt which is between min and max and calls glColor. @param wrt value for which a color should be assigned. @param min minimum value of wrt.  @param max maximum value of wrt.
   Cell cell;//!<The unit cell parameters
   QString Fragments;//!<A html string of the kind "<b>The asymmetric unit contains N fragments.</b><br>" were N is the number of fragments.
@@ -1179,6 +1203,11 @@ public:
   //
   QStringList sdmcompleter();
   void atoms(CEnvironment atom,int proba=50);
+  bool shaders_work;//!< can glsl shader run on this machine?
+  bool program_in_use;//!< glsl program active 
+  bool useShaders;//!< the user whats shader
+  void shaderAtoms(CEnvironment atom,int proba=50);//!< like void atoms(CEnvironment atom,int proba=50); but with shaders
+  void pappe();//!< the inner walls of an ellipsoid (use ony with shaders and 'wall' uniform set)
   void bonds(Connection bond);
   void dbond(Connection bond);
   void lbond();
@@ -1207,6 +1236,7 @@ public:
   void cellSetup();//!< calculates unit cell parameters from a,b,c, alpha, beta, gammma
   void fuse();
   void grow();
+  void grow_plus();
   void fillCell();
   void uniqueInCell();
   void packer(QStringList brauchSymm);
@@ -1214,25 +1244,39 @@ public:
   void Uf2Uo(const Matrix x, Matrix & y) ;
   void Usym (Matrix x,Matrix sym, Matrix & y);
   double dimension();
+  double dimension(CEnvironment ce);
   void expandAt(int index);
   void expandAll();
   void complete();
   void enviSDM(double range);
   QString pse(int oz);//!< returns the chemical symbol for the given atomic number (starting from 0)
   void loadSettings();
-  void ikosa(double R);//!< draws an icosahedron with radius R. @param R radius in Anstrom.
+  void dodecaeder(GLfloat r);
+  void icosaeder(GLfloat r);
+  void triacontaeder(GLfloat r);
+  void cube(GLfloat r);
   int maxmols(){return maxmol;}//!< returns the number of fragments (molecules)
 private:
+  bool checkExtensions();
   double HAMax,HAWink;
   void ellipse(int style);
   void hirsh(Connection bond);
-  void sphere(int adp);
-  void dCube(GLfloat rad);
+  void sphere(int adp,int style=7);
+  void mySphere(int bal);
 //  void ikosa(double R);
 //  V3 eigenvalues(const Matrix m);
 //  Matrix eigenvectors(const Matrix m,const V3 l);
   double * jacobi(const Matrix &uij, V3 &ev);
 int maxmol;
 
+int lichtH;
+int whiteringH;
+int wallH;
+int ballH;
+int ringH;
+int openH;
+int adpsH;
+int Licht;
+int lodH;
 };
 #endif
