@@ -24,7 +24,6 @@ QStringList shxToolTips =(QStringList()<<
 "TWIN 3x3 matrix [-1 0 0 0 -1 0 0 0 -1] n[2]"<<
 "EXTI x[0]"<<
 "SWAT g[0] U[2]"<<
-"HOPE nh [1]"<<
 "MERG n[2]"<<
 "SPEC del[0.2]"<<
 "RESI class[ ] number[0] alias"<<
@@ -92,7 +91,9 @@ QStringList shxToolTips =(QStringList()<<
 "ANSC six coefficients\nanisotropic scaling"<<
 "ANSR [0.001] restraint for ANSC "<<
 "NOTR p[170] d[1.9] cremoves torsion angles generated by CONF from the .cif file"<<
-"TWST N[0] specify twin component used for completeness and friedel statictics"//<<
+"TWST N[0] specify twin component used for completeness and friedel statictics"<<
+"BEDE atom1 atom2 r A U1 U2"<<
+"LONE m atomnames A U1 U2 r phi\nphi required for m = 2, 3, 7, 9, and 12"//<<
 );
 
 
