@@ -20,7 +20,6 @@
 #define WINDOW_H
 #include <QtGui>
 #include <QtNetwork>
-// #include <QtWebKit>
 #include "chgl.h"
 #include "highlighter.h"
 #include "codeeditor.h"
@@ -42,10 +41,14 @@
 #undef vc7hack1
 #ifdef _MSC_VER
 #include <float.h>
-int finite(double arg);
+#define std_isfinite _finite
 #define vc7hack1 1
+#else
+#define std_isfinite std::isfinite
 #endif
 #include "calculator.h"
+#include "dsrgui.h"
+#include "listfile.h"
 
 /*! \brief Window is the main window class of ShelXle most of the magic happens here ;-)
 *
@@ -59,7 +62,7 @@ public:
   //bool scroller;
   ChGL *chgl;  
   QDockWidget *dock, *renamDock, *qPeakDock, *histDock;
-  QDockWidget *shxEditorDock,*shxOutputDock;
+  QDockWidget *shxEditorDock,*shxOutputDock,*infotainmentDock;
   QAction *enterRenameMode,*showQPeakLegend;
   QToolBar *editToolBar,//!< Edit toolbar (redo undo copy cut and paste...) +kill Hs, kill Qs, refine XL and anis refine
            *bottomToolBar,//!< selection toolbar with context specific content.
@@ -78,6 +81,7 @@ public:
   QHash<QString,QVariant> myHash;//!< This Hash connects recent file names with cursor positions. So that files are opened always at the same position.
   QAction *refineAct;
   QAction *refineActAnis;
+  QAction *refineActActa;
   double map_radius; //!< radius of the map in Angstrom around the rotaion center (used only in a mode of FourXle).
   FourXle *fxle;//!<The fourier map object.
 //  QList<V3> orte;
@@ -88,8 +92,11 @@ public:
   QList<double> fvar;//!<List of Free Variables.
   QMap<int,int> fvarCntr;//!<Free Variable counter QMap.
   bool isLabelInUse();//!< Checks if the current Label in the reaname dialog is in use. \returns true if Label is already in use.
-  public slots:
-	  
+  QString dirName;
+  void setFocus(bool b){focusSet=b;}
+  bool isFocusSet() {return focusSet;}
+
+public slots:
   void qinitres();
   void about();//!<Shows the about dialog of ShelXle.
   void addNewScatteringFactor(int oz);//!<Adds a new scattering factor to the SFAC / UNIT list.
@@ -126,6 +133,7 @@ public:
   void deleteAllQ();//!<Deletes all Q-Peaks.
   void deleteSelectedAtoms();//!<Deletes all selected atoms.
   void dispFromWave();//!<calculates f', f" and mu for the given wavelength and inserts DISP lines for each SFAC entry.
+  void displayResiduals(XLOutputParser &lfo, QString s);
   void doMapsNow(bool b);//!<destroys maps or (re)calculates them freshly.
   int duplicates();//!<searches for identical labeled Atoms and add them to a list. 
   void editorIsVisible(bool);//!is Editor really visble
@@ -157,7 +165,8 @@ public:
   void increaseEdtiorFont();//!< Increases the editor font by one point.
   void infoKanalNews(const QString& s);//!< passes a string to the Info widget. @param s a new text for the info widget.
   void inheritLabels();//!< opens an inherit labels dialog.
-  bool insertAnis();//!< inserts anis instruction into the file.
+  bool insertAnis();//!< inserts ANIS instruction into the file.
+  bool insertActa();//!< inserts ACTA instruction into the file.
   void insertBind();//!< inserts a BIND instruction into the file.
   void insertFree();//!< inserts a FREE instruction into the file.
   void insertList6();//!< inserts a LIST 6 instruction into the file.
@@ -194,6 +203,8 @@ public:
   void insertCHIV(double vol, double esd1, QList<MyAtom> selected, QString resiSpec=""); //!< Insert CHIV restraint into ins file
   void insertANIS(QList<MyAtom> selected); //!< Insert ANIS for selected atoms
 //  bool peakcomp(MyAtom &a1,MyAtom &a2);
+  void raiseTaff();// show visual refinement output
+  void raiseTaz();// show text refinement output
   void redoRename();//!<if redo is clicked and it was a rename a rename is redone.
   void removeExtra(QAbstractButton *button);//!<removes an external program from the menu / tool bar.
   void renameRNchanged(int ii);//!< Residue Number of rename mode is changed to ii @param ii residue number.
@@ -218,6 +229,7 @@ public:
   void schnittart(int trunc);//!< the truncation type of the electron density maps changes to trunc @param trunc new truncation type.
   void sdm();//!< the shortest distance matrix is (re)calculated and the structure is grown
   void selectInStructure(const QString &info);//!< selects all atoms found in selected text in the structure @params info seleted text. 
+  void sortSelectedRegion();//!< sorts all atoms found in selected text in the structure @params info seleted text.
   void selectParts();//!< selects atoms for 'Part Selector'
   void setShelxlOptions();//!< sets path and command line options for ShelXl executable.
   void setShelxlPath();//!< sets path for ShelXl executable
@@ -264,12 +276,19 @@ public:
   void zoomin(); //!< zoomes in 
   void zoomout();//!< zoomes out 
   void calculator(); //!< A dialog to work with resolution and 1,3 distances via the angle
+  void create_DSRGui(); //!< A dialog for DSR
+  void insertDSRLine(QString dsrline, int position, QVector<int> previousLine);
+  void aboutDSR(); //!<Shows the about dialog of the DSR GUI.  
+  void dsrClosed();
+  static int isacommand(QString command);
+  void displayDisagreeableRestraints();
 protected:
   void paintEvent(QPaintEvent *event);
   void moveEvent(QMoveEvent *event);
   void dragEnterEvent(QDragEnterEvent *event);
   void dropEvent(QDropEvent *event);
 private:
+  bool focusSet;
   int sortierWeise;
   int cycls;
   QNetworkAccessManager *net;
@@ -339,7 +358,7 @@ private:
   QRadioButton *pserbt[110];
   QGroupBox *sfacBox;
   double scalePic;
-  QString saveName,dirName,fvarinfo;
+  QString saveName,fvarinfo;
   QProcess *shelxl,*extraProc;
   QDialog *extraOutput;
   QTextEdit *extraOutPut;
@@ -354,6 +373,7 @@ private:
   //QTextBrowser *hilfe;
   QWidget *shx_group;
   QVBoxLayout *sss,*amdl;
+  QVBoxLayout *hwl;
   QHBoxLayout *nlt;
   QGroupBox *renameBox ;
   QVBoxLayout *rnla;    
@@ -362,9 +382,6 @@ private:
   QScrollArea *qsa,*qsa2;
   QAction *zm_stereo, *pe_stereo, *xe_stereo, *an_stereo, *hw_stereo, *no_stereo; 
   QAction *fcvsfoAct, *calcAct;
-
-
-
   QAction *soact;
   QAction *backColor,*labelColor;
   QVBoxLayout *lt;
@@ -378,15 +395,16 @@ private:
   QPushButton *applyMC;          
   QPushButton *applyDF;          
   QLabel *wl, *pl, *dl, *ol, *rl, *sl, *lw, *ltz;
-
-
-
-
   QHBoxLayout *indexla;
   QStringList alpha;
   QGridLayout *slt,*scalla,*mdl;
   QHBoxLayout *slt2;       
-  QVBoxLayout *vlt;
+  QVBoxLayout *vlt, *resid_layout;
+  QTextEdit *resid_label; //! display the refinement residuals
+  QTextEdit *restr_table; //! display the bad restraints
+  //RenderPlot *plot;
+  LstData listf_info;
+  QGroupBox *resid_gb;
   QGroupBox *gp;QHBoxLayout *rhla,*rhla2; 
   QHBoxLayout *buttomLt;
   QPushButton *showLst;
@@ -400,15 +418,19 @@ private:
   QPoint ediPos;
   QComboBox *resiFinder;
   QLabel *lineColumn;
-  QGroupBox *suchbox2,*suchbox,*navibox,*refineButtonBox;
+  QGroupBox *suchbox2,*suchbox,*navibox,*refineButtonBox,*refineButtonBox2;
   QPushButton *stoppRefinement;
   QPushButton *loadRes;
   QPushButton *withdraw;
+  
+  QPushButton *stoppRefinement2;// this is for infotainment dock
+  QPushButton *loadRes2;
+  QPushButton *withdraw2;
   QToolButton *spellCheckact,*spellCheckact2;
   QAction
 	  *tubeStyle,
 	  *ballStyle,
-          *separateLabelFile,
+      *separateLabelFile,
       *toggleOrthoView,
       *actionUniq,
       *actionSearch,
@@ -430,20 +452,18 @@ private:
       *togUnit,
       *togElli,
       *togHBond,
-      *togDepthCueing,
-      *togXRayView,
       *togBackGr,
       *killQs,
       *killHs,
       *astdlg,
-  *equivHighlighting,
+      *equivHighlighting,
       *mapcontrol,
       *wghtAct,
       *sinaAct;
+  QSettings *vis_settings;
   void searchchanged(bool current,bool back);
   void searchchanged2(bool current,bool back);
   void shx_editor(QString filename,QString title);
-  int isacommand(QString command);
   double getNumber(double v,const QList<double> fv,double uiso);//to be changed!
   double getNumber(double v,const QList<double> fv,int idx,int &fixFlag);//to be changed!
   double ueq(Matrix m);
@@ -453,6 +473,11 @@ private:
   bool maybeSave2();
   bool ediVis,oupVis,startFused;
   Calculator *calcmenu;
+  DSRGui *dsr;
+  int firstAtomLine;
+signals:
+  void fileLoaded(void);
+
 };
 #endif
 
